import tensorflow as tf


def normalise(adjacency_matrices):
    """Normalises adjacency matricies

    This will normalise (scale all rows to sum to one) a set of
    adjacency matricies.

    Args:
        adjacency_matrices: The input tensor of adjacency matricies (can be
        of any rank of at least two, with the adjacency matricies in the last
        two dimensions).

    Returns:
        The resulting tensor of adjacency matricies.
    """
    degree = tf.reduce_sum(adjacency_matrices, axis=-2)
    degree = tf.expand_dims(degree, -1)
    return tf.math.divide_no_nan(adjacency_matrices, degree)
